# -*- coding: utf-8 -*-

# Copyright 2016 Mir Calculate. http://www.calculate-linux.org
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import sys

from calculate.lib.datavars import VariableError, DataVarsError

from calculate.core.server.func import WsdlBase
from .unix import Unix, UnixError
from calculate.ldap.ldap import LdapError
from calculate.server.variables.action import Actions as ServerActions
from utils.cl_unix_setup import ClUnixSetupAction

_ = lambda x: x
from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate

setLocalTranslate('cl_unix3', sys.modules[__name__])
__ = getLazyLocalTranslate(_)


class Wsdl(WsdlBase):
    methods = [
        #
        # Настроить службу
        #
        {
            # идентификатор метода
            'method_name': Unix.Method.Setup,
            # категория метода
            'category': __('Unix'),
            # заголовок метода
            'title': __("Setup"),
            # иконка для графической консоли
            'image': 'setup',
            # метод присутствует в графической консоли
            'gui': True,
            # консольная команда
            'command': 'cl-unix-setup',
            # права для запуска метода
            'rights': ['unix'],
            # объект содержащий модули для действия
            'logic': {'Unix': Unix},
            # описание действия
            'action': ClUnixSetupAction,
            # объект переменных
            'datavars': "unix",
            'native_error': (VariableError, DataVarsError, LdapError, UnixError),
            # значения по умолчанию для переменных этого метода
            'setvars': {'cl_action!': ServerActions.Setup,
                        'server.cl_server_name!': "unix",
                        'cl_autoupdate_set': 'on'
                      #  'cl_dispatch_conf_default': "usenew"
                        },
            # описание груп (список лямбда функций)
            'groups': [
                lambda group: group(
                    _("Unix server"),
                    brief=('ldap.ld_base_dn',),
                    hide=(),
                    normal=(),
                    expert=()),
                ],
                'brief': {'next': __("Perform"),
                      'name': __("Setup Unix"),}
            },
    ]
